@@ -7,7 +7,7 @@ from forcebalance.gmxio import GMX
 from forcebalance.tinkerio import TINKER
 from forcebalance.openmmio import OpenMM
 from collections import OrderedDict
-from .__init__ import ForceBalanceTestCase
+from .__init__ import ForceBalanceTestCase, check_for_openmm
 
 # Set SAVEDATA to True and run the tests in order to save data
 # to a file for future reference. This is easier to use for troubleshooting
@@ -86,18 +86,21 @@ class TestAmber99SB(ForceBalanceTestCase):
         if gmxpath != '':
             cls.engines['GMX'] = GMX(coords="all.gro", gmx_top="topol.top", gmx_mdp="shot.mdp", gmxpath=gmxpath, gmxsuffix=gmxsuffix)
         else:
-            logger.warn("GROMACS cannot be found, skipping GMX tests.")
+            logger.warning("GROMACS cannot be found, skipping GMX tests.")
         # Set up TINKER engine
         if tinkerpath != '':
             cls.engines['TINKER'] = TINKER(coords="all.arc", tinker_key="alaglu.key", tinkerpath=tinkerpath)
         else:
-            logger.warn("TINKER cannot be found, skipping TINKER tests.")
+            logger.warning("TINKER cannot be found, skipping TINKER tests.")
         # Set up OpenMM engine
         try:
-            import simtk.openmm
+            try:
+                import openmm
+            except ImportError:
+                import simtk.openmm
             cls.engines['OpenMM'] = OpenMM(coords="all.gro", pdb="conf.pdb", ffxml="a99sb.xml", platname="Reference", precision="double")
         except:
-            logger.warn("OpenMM cannot be imported, skipping OpenMM tests.")
+            logger.warning("OpenMM cannot be imported, skipping OpenMM tests.")
 
     @classmethod
     def teardown_class(cls):
@@ -348,6 +351,7 @@ class TestAmoebaWater6(ForceBalanceTestCase):
     """
     @classmethod
     def setup_class(cls):
+        if not check_for_openmm(): pytest.skip("No OpenMM modules found.")
         super(TestAmoebaWater6, cls).setup_class()
         #self.logger.debug("\nBuilding options for target...\n")
         cls.cwd = os.path.dirname(os.path.realpath(__file__))
